# Check style and quality

Style and quality checks run through [pre-commit](https://pre-commit.com).

## Setup

Run `pre-commit install` once, and from then on pre-commit will run automatically every
time you commit.

## Manual checks

Run `pre-commit run -a` to run all checks manually.
